@@ -6,11 +6,13 @@ class secure_socket(socket.socket):
     def __init__(s, family=-1, type=-1, proto=-1, fileno=None, privatekey:int=None):
        super().__init__(family, type, proto, fileno)
        s.keypair=dh.DiffieHellman()
+       s.shared=s._tobytes(0)
        if privatekey!=None:
           s.keypair._DiffieHellman__a=privatekey
     @classmethod
     def _tobytes(t,a:int)->bytes:
         l=[]
+        if a==0:return bytes([0])
         while a!=0:
             l+=[a%256]
             a=a//256
@@ -51,15 +53,17 @@ class secure_socket(socket.socket):
         """
         Setup asymmetric encryption. the other side should also run this to complete
         """
+        s.setblocking(True)
         key=s._tobytes(s.keypair.gen_public_key())
-        s.send(key+b"0"*(256-len(key)))
-        s.shared=s._tobytes(int(s.keypair.gen_shared_key(s._frombytes(s.recv(256))),16))
+        s.encrypted_send(key+b"0"*(256-len(key)))
+        s.shared=s._tobytes(int(s.keypair.gen_shared_key(s._frombytes(s.encrypted_recv(256))),16))
         s.setblocking(False)
     def set_key(s,key:int):
         """
         Set a integer as encryption key. 
         """
         s.shared=s._tobytes(key)
+        s.setblocking(False)
     def encrypted_send(s,data):
         """
         Encrypts data and sends it.
